@@ -18,7 +18,7 @@ class TimeLineEntry(EntryBlock):
         item = {
             'type': 'text',
             'value': {
-                'value': self.mocker.xs
+                'value': self.xs
             }
         }
         self.mock_data.update({
