@@ -77,6 +77,19 @@ if not is_model_registered('cms', 'FormSubmission'):
 
     __all__.append('FormSubmission')
 
+
+from .snippets.person import APerson
+
+
+if not is_model_registered('cms', 'Person'):
+    @register_snippet
+    class Person(APerson):
+        pass
+
+
+    __all__.append('Person')
+
+
 #  Pages
 
 
