@@ -1,3 +1,5 @@
+import AccordionPure from './Accordion';
+
 function createElementFromHTML(htmlString) {
   const div = document.createElement('div');
   div.innerHTML = htmlString.trim();
@@ -123,11 +125,11 @@ const Clicker = {
   },
 };
 
-const Accordion = {
-  init: () => {
-    const accordion = document.getElementById('accordion');
-    const accordionOpen = document.getElementById('accordion-open');
-    const accordionClose = document.getElementById('accordion-close');
+const Aside = {
+  mobile: () => {
+    const accordion = document.getElementById('aside-mobile');
+    const accordionOpen = document.getElementById('aside-mobile-open');
+    const accordionClose = document.getElementById('aside-mobile-close');
 
     if (accordion) {
       document.addEventListener('click', (e) => {
@@ -174,6 +176,7 @@ const Collect = {
     const haveAccepted = localStorage.getItem('collect');
 
     if (!(haveAccepted && haveAccepted === 'false')) {
+      collectBlock.children[0].style.display = 'flex';
       collectButton.addEventListener('click', (e) => {
         e.stopPropagation();
         collectBlock.style.display = 'none';
@@ -185,12 +188,60 @@ const Collect = {
   },
 };
 
+
+const Accordion = {
+  init: () => {
+    const accordions = Array.from(document.querySelectorAll('.accordion-container'));
+    if (accordions) {
+      accordions.forEach((item) => {
+        new AccordionPure(`#${item.id}`, {
+          duration: 300,
+        });
+      });
+    }
+  },
+};
+
+const CounterUp = {
+  init: () => {
+    const io = new IntersectionObserver(entries => entries.forEach((item) => {
+      const element = item.target;
+      if (item.isIntersecting) {
+        const number = Number(element.textContent) + 1;
+
+        let counter = 0;
+        let delay = 1;
+        const x = number / 2;
+        let y = 0;
+
+        function counterJs() {
+          y += 1;
+          delay = (x - y);
+          element.innerHTML = counter.toString();
+          counter += 1;
+          if (counter < number) {
+            setTimeout(() => {
+              counterJs();
+            }, delay);
+          }
+        }
+
+        counterJs();
+        io.unobserve(element);
+      }
+    }));
+    document.querySelectorAll('.counter-up').forEach(element => io.observe(element));
+  },
+};
+
 export default {
   Image,
   Carousel,
   SmoothScroll,
   Clicker,
-  Accordion,
+  Aside,
   Lazy,
   Collect,
+  Accordion,
+  CounterUp,
 };
